==> jc-1.4.0.tar.gz: org/dellroad/jc/vm/FinalizerThread.h <==
// class org.dellroad.jc.vm.FinalizerThread

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread
// @dep_class fc1d06e31edae9b3 org_dellroad_jc_vm_FinalizerThread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_org_dellroad_jc_vm_FinalizerThread_H_
#define _JC_org_dellroad_jc_vm_FinalizerThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_refs	_jc_org_dellroad_jc_vm_FinalizerThread$sub_refs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs	_jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$refs	_jc_org_dellroad_jc_vm_FinalizerThread$refs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$nonrefs	_jc_org_dellroad_jc_vm_FinalizerThread$nonrefs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$object	_jc_org_dellroad_jc_vm_FinalizerThread$object;

typedef const struct _jc_org_dellroad_jc_vm_FinalizerThread$vmethods	_jc_org_dellroad_jc_vm_FinalizerThread$vmethods;
typedef const struct _jc_org_dellroad_jc_vm_FinalizerThread$vtable	_jc_org_dellroad_jc_vm_FinalizerThread$vtable;
typedef const struct _jc_org_dellroad_jc_vm_FinalizerThread$vtype	_jc_org_dellroad_jc_vm_FinalizerThread$vtype;

// Constructors
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *);
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$waitForInterrupt$b5ec245748f14f03(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_vm_FinalizerThread$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_org_dellroad_jc_vm_FinalizerThread$method_info$waitForInterrupt$b5ec245748f14f03;

// Static methods
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$finalizeObjects$19c740798b70afba(_jc_env *);

// Virtual methods structure
struct _jc_org_dellroad_jc_vm_FinalizerThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *);
	void	(*waitForInterrupt$b5ec245748f14f03)(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *);
};

// Vtable
struct _jc_org_dellroad_jc_vm_FinalizerThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_org_dellroad_jc_vm_FinalizerThread$vmethods	org_dellroad_jc_vm_FinalizerThread;
};

// Vtype
struct _jc_org_dellroad_jc_vm_FinalizerThread$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_vm_FinalizerThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_vm_FinalizerThread$refs {
    _jc_org_dellroad_jc_vm_FinalizerThread$sub_refs	org_dellroad_jc_vm_FinalizerThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_vm_FinalizerThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs	org_dellroad_jc_vm_FinalizerThread;
};

// Object instance structure
struct _jc_org_dellroad_jc_vm_FinalizerThread$object {
	_jc_org_dellroad_jc_vm_FinalizerThread$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_vm_FinalizerThread$vtype	*vtype;
	_jc_org_dellroad_jc_vm_FinalizerThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_vm_FinalizerThread$vtype _jc_org_dellroad_jc_vm_FinalizerThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_vm_FinalizerThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_vm_FinalizerThread$class_object;

#endif	/* _JC_org_dellroad_jc_vm_FinalizerThread_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/vm/FinalizerThread.h <==
// class org.dellroad.jc.vm.FinalizerThread

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread
// @dep_class fc1d06e31edae9b3 org_dellroad_jc_vm_FinalizerThread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_org_dellroad_jc_vm_FinalizerThread_H_
#define _JC_org_dellroad_jc_vm_FinalizerThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_refs	_jc_org_dellroad_jc_vm_FinalizerThread$sub_refs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs	_jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$refs	_jc_org_dellroad_jc_vm_FinalizerThread$refs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$nonrefs	_jc_org_dellroad_jc_vm_FinalizerThread$nonrefs;
typedef struct _jc_org_dellroad_jc_vm_FinalizerThread$object	_jc_org_dellroad_jc_vm_FinalizerThread$object;

typedef const struct _jc_org_dellroad_jc_vm_FinalizerThread$vmethods	_jc_org_dellroad_jc_vm_FinalizerThread$vmethods;
typedef const struct _jc_org_dellroad_jc_vm_FinalizerThread$vtable	_jc_org_dellroad_jc_vm_FinalizerThread$vtable;
typedef const struct _jc_org_dellroad_jc_vm_FinalizerThread$vtype	_jc_org_dellroad_jc_vm_FinalizerThread$vtype;

// Constructors
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$waitForInterrupt$b5ec245748f14f03(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_vm_FinalizerThread$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_org_dellroad_jc_vm_FinalizerThread$method_info$waitForInterrupt$b5ec245748f14f03;

// Static methods
extern void _jc_org_dellroad_jc_vm_FinalizerThread$method$finalizeObjects$19c740798b70afba(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_vm_FinalizerThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *) _JC_JCNI_ATTR;
	void	(*waitForInterrupt$b5ec245748f14f03)(_jc_env *, struct _jc_org_dellroad_jc_vm_FinalizerThread$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_vm_FinalizerThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_org_dellroad_jc_vm_FinalizerThread$vmethods	org_dellroad_jc_vm_FinalizerThread;
};

// Vtype
struct _jc_org_dellroad_jc_vm_FinalizerThread$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_vm_FinalizerThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_vm_FinalizerThread$refs {
    _jc_org_dellroad_jc_vm_FinalizerThread$sub_refs	org_dellroad_jc_vm_FinalizerThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_vm_FinalizerThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_org_dellroad_jc_vm_FinalizerThread$sub_nonrefs	org_dellroad_jc_vm_FinalizerThread;
};

// Object instance structure
struct _jc_org_dellroad_jc_vm_FinalizerThread$object {
	_jc_org_dellroad_jc_vm_FinalizerThread$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_vm_FinalizerThread$vtype	*vtype;
	_jc_org_dellroad_jc_vm_FinalizerThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_vm_FinalizerThread$vtype _jc_org_dellroad_jc_vm_FinalizerThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_vm_FinalizerThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_vm_FinalizerThread$class_object;

#endif	/* _JC_org_dellroad_jc_vm_FinalizerThread_H_ */
